@@ -1,12 +1,12 @@
 package File::RsyBak;
 
-our $DATE = '2015-04-22'; # DATE
-our $VERSION = '0.25'; # VERSION
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.26'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use File::chdir;
 
@@ -382,7 +382,7 @@ File::RsyBak - Backup files/directories with histories, using rsync
 
 =head1 VERSION
 
-This document describes version 0.25 of File::RsyBak (from Perl distribution File-RsyBak), released on 2015-04-22.
+This document describes version 0.26 of File::RsyBak (from Perl distribution File-RsyBak), released on 2015-08-17.
 
 =head1 SYNOPSIS
 
@@ -400,7 +400,7 @@ Or, just use the provided script from the command-line:
 
  % rsybak --source /path/to/mydata --target /backup/mydata --extra-rsync-opts-json '["--exclude","Cache","--exclude","cache","--exclude","tmp","--exclude","temp"]'
 
-Or, if you have this configuration in C</etc/rsybak.conf> or <~/rsybak.conf>:
+Or, if you have this configuration in C</etc/rsybak.conf> or C<~/rsybak.conf>:
 
  [system]
  source = /path/to/mydata
@@ -501,7 +501,7 @@ on those platforms.
 
 =head2 backup(%args) -> [status, msg, result, meta]
 
-Backup files/directories with histories, using rsync.
+{en_US Backup files/directories with histories, using rsync}.
 
 Examples:
 
@@ -512,15 +512,18 @@ Arguments ('*' denotes required arguments):
 
 =item * B<backup> => I<bool> (default: 1)
 
-Whether to do backup or not.
+{en_US Whether to do backup or not}.
 
+{en_US 
 If backup=1 and rotate=0 then will only create new backup without rotating
 histories.
+}
 
 =item * B<extra_dir> => I<bool>
 
-Whether to force creation of source directory in target.
+{en_US Whether to force creation of source directory in target}.
 
+{en_US 
 If set to 1, then backup(source => '/a', target => '/backup/a') will create
 another 'a' directory in target, i.e. /backup/a/current/a. Otherwise, contents
 of a/ will be directly copied under /backup/a/current/.
@@ -528,36 +531,43 @@ of a/ will be directly copied under /backup/a/current/.
 Will always be set to 1 if source is more than one, but default to 0 if source
 is a single directory. You can set this to 1 to so that behaviour when there is
 a single source is the same as behaviour when there are several sources.
+}
 
 =item * B<extra_rsync_opts> => I<array[str]>
 
-Pass extra options to rsync command.
+{en_US Pass extra options to rsync command}.
 
+{en_US 
 Extra options to pass to rsync command when doing backup. Note that the options
 will be shell quoted, , so you should pass it unquoted, e.g. ['--exclude',
 '/Program Files'].
+}
 
 =item * B<histories> => I<array[int]> (default: [-7,4,3])
 
-Histories/history levels.
+{en_US Histories/history levels}.
 
+{en_US 
 Specifies number of backup histories to keep for level 1, 2, and so on. If
 number is negative, specifies number of days to keep instead (regardless of
 number of histories).
+}
 
 =item * B<rotate> => I<bool> (default: 1)
 
-Whether to do rotate after backup or not.
+{en_US Whether to do rotate after backup or not}.
 
+{en_US 
 If backup=0 and rotate=1 then will only do history rotating.
+}
 
 =item * B<source>* => I<str>
 
-Director(y|ies) to backup.
+{en_US Director(y|ies) to backup}.
 
 =item * B<target>* => I<str>
 
-Backup destination.
+{en_US Backup destination}.
 
 =back
 
@@ -735,7 +745,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/File-RsyBa
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-File-RsyBak>.
+Source repository is at L<https://github.com/sharyanto/perl-File-RsyBak>.
 
 =head1 BUGS
 
